@@ -36,7 +36,7 @@ for (i in 1:4) {
 data <- data.frame(data)
 names(data) <- paste0("x",1:4)
 
-fulldata <- cbind(data, age=rep(age,each=Nsub),ses=rep(ses,each=Nsub))
+fulldata <- cbind(data, age=factor(rep(age,each=Nsub)),ses=factor(rep(ses,each=Nsub)))
 #
 model<-"
 ! regressions 
@@ -88,7 +88,7 @@ ctr <- semtree.control(verbose=TRUE)
 ctr$exclude.heywood <- FALSE
 # naive tree should find both effects, age & ses, with age having the stronger effect 
 tree <- semtree(model = result, data=fulldata, control=ctr )
-plot(tree)
+#plot(tree)
 
 # invariance tree should exclude splits wrt age and only splir wrt to ses
 ctr$report.level <- 99
@@ -98,11 +98,4 @@ cnst <- semtree.constraints(local.invariance = c("l2","l3","l4"))
 #cnst <- semtree.constraints(local.invariance=)
 tree2 <- semtree(model = result, data=fulldata, control=ctr, constraints = cnst )
 
-plot(tree2)
-
-ctr <- semtree.control(method="fair")
-tree3 <- semtree(model = result, data=fulldata, control=ctr)
-
-
-ctr <- semtree.control(method="cv")
-tree4 <- semtree(model = result, data=fulldata, control=ctr)
+#plot(tree2)
